==> satellite-4.2.2.tar.gz: satellite-4.2.2/modules/gpm/command/graph_sub.h <==
/* 
 * Copyright (c) 2003 RIKEN (The Institute of Physical and Chemical Research)
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY RIKEN AND CONTRIBUTORS ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL RIKEN OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

/* $SATELLITE: satellite4/modules/gpm/command/graph_sub.h,v 1.4 2004/08/11 13:58:02 orrisroot Exp $ */

#ifndef _GPMPRIV_GRAPHSUB_H_
#define _GPMPRIV_GRAPHSUB_H_

#ifdef __cplusplus
extern "C" {
#endif

/* graph_sub.c */
int  gpmcmd_open_window();
void gpmcmd_close_window();
void gpmcmd_disp_scale_mode(int mode1, int mode2);
void gpmcmd_btof(int dim, int *index, Buffer *buf, float **data);
void gpmcmd_set_data(int type, int dim, int *index, Buffer *buf);
void gpmcmd_set_scale();
void gpmcmd_get_draw_scale(float *xMin, float *xMax, float *yMin, float *yMax);
void gpmcmd_set_xscale(float **xdata, int n, int m, int is);
void gpmcmd_set_yscale(float **ydata, int n, int m, int is);
int  gpmcmd_zerop(int n_series, float **data);

#ifdef __cplusplus
}
#endif

#endif /* _GPMPRIV_GRAPHSUB_H_ */

==> satellite-4.2.3.tar.gz: satellite-4.2.3/modules/gpm/command/graph_sub.h <==
/* 
 * Copyright (c) 2003-2005 RIKEN Japan, All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY RIKEN AND CONTRIBUTORS ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL RIKEN OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

/* $SATELLITE: satellite4/modules/gpm/command/graph_sub.h,v 1.6 2005/04/06 08:42:15 orrisroot Exp $ */

#ifndef _GPMPRIV_GRAPHSUB_H_
#define _GPMPRIV_GRAPHSUB_H_

#ifdef __cplusplus
extern "C" {
#endif

/* graph_sub.c */
int  gpmcmd_open_window(gpm_cont_t *gpm_cont);
void gpmcmd_close_window();
void gpmcmd_btof(int dim, int *index, Buffer *buf, float **data);
void gpmcmd_set_data(int type, int dim, int *index, Buffer *buf);
void gpmcmd_set_xscale(gpm_cont_t *gpm_cont, 
                       float **xdata, int n, int m, int is);
void gpmcmd_set_yscale(gpm_cont_t *gpm_cont, 
                       float **ydata, int n, int m, int is);
void gpmcmd_set_scale(gpm_cont_t *gpm_cont);
void gpmcmd_get_draw_scale(gpm_cont_t *gpm_cont, 
                           float *xMin, float *xMax, float *yMin, float *yMax);
void gpmcmd_disp_scale_mode(int mode1, int mode2);
int  gpmcmd_zerop(int n_series, float **data);

#ifdef __cplusplus
}
#endif

#endif /* _GPMPRIV_GRAPHSUB_H_ */
